;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "diff-hl" "20260613.127"
  "Highlight uncommitted changes using VC."
  '((cl-lib "0.2")
    (emacs  "27.1"))
  :url "https://github.com/dgutov/diff-hl"
  :commit "2f1623d98a29cee791fac2b879a45d53eec3ba82"
  :revdesc "2f1623d98a29"
  :keywords '("vc" "diff")
  :authors '(("Dmitry Gutov" . "dmitry@gutov.dev"))
  :maintainers '(("Dmitry Gutov" . "dmitry@gutov.dev")))
